@@ -9,9 +9,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -30,32 +30,32 @@
  * @package UnitTest
  * @version //autogentag//
  */
-class ezcTestConstraintSimilarImage extends PHPUnit\Framework\Constraint
+class ezcTestConstraintSimilarImage extends PHPUnit\Framework\Constraint\Constraint
 {
     /**
      * Filename of the image to compare against.
-     * 
+     *
      * @var string
      */
     protected $filename;
 
     /**
      * Maximum delta between images.
-     * 
+     *
      * @var int
      */
     protected $delta;
 
     /**
      * Difference between images.
-     * 
+     *
      * @var int
      */
     protected $difference;
 
     /**
      * Constructor.
-     * 
+     *
      * @param string $filename Filename of the image to compare against.
      * @param int $delta Maximum delta between images.
      * @return ezcConstraintSimilarImage
@@ -93,7 +93,7 @@ class ezcTestConstraintSimilarImage extends PHPUnit\Framework\Constraint
             throw new ezcBaseFileNotFoundException( $other );
         }
 
-        $descriptors = array( 
+        $descriptors = array(
             array( 'pipe', 'r' ),
             array( 'pipe', 'w' ),
             array( 'pipe', 'w' ),
@@ -105,30 +105,30 @@ class ezcTestConstraintSimilarImage extends PHPUnit\Framework\Constraint
         );
 
         $imageProcess = proc_open( $command, $descriptors, $pipes );
-        
+
         // Close STDIN pipe
         fclose( $pipes[0] );
-        
+
         $errorString = '';
-        // Read STDERR 
-        do 
+        // Read STDERR
+        do
         {
-            $errorString .= rtrim( fgets( $pipes[2], 1024) , "\n" );
+            $errorString .= rtrim( fgets( $pipes[2], 1024 ) , "\n" );
         } while ( !feof( $pipes[2] ) );
-        
+
         $resultString = '';
-        // Read STDOUT 
-        do 
+        // Read STDOUT
+        do
         {
-            $resultString .= rtrim( fgets( $pipes[1], 1024) , "\n" );
+            $resultString .= rtrim( fgets( $pipes[1], 1024 ) , "\n" );
         }
         while ( !feof( $pipes[1] ) );
-        
+
         // Wait for process to terminate and store return value
         $return = proc_close( $imageProcess );
 
         // Some versions output to STDERR
-        if ( empty( $resultString) && !empty( $errorString ) )
+        if ( empty( $resultString ) && !empty( $errorString ) )
         {
             $resultString = $errorString;
         }
@@ -154,34 +154,35 @@ class ezcTestConstraintSimilarImage extends PHPUnit\Framework\Constraint
      * @param   boolean $not Flag to indicate negation.
      * @throws  PHPUnit\Framework\ExpectationFailedException
      */
-    public function fail( $other, $description, SebastianBergmann\Comparator\ComparisonFailure  $comparisonFailure = NULL )
+    public function fail( $other, $description, SebastianBergmann\Comparator\ComparisonFailure $comparisonFailure = NULL ) : void
     {
         $failureDescription = sprintf(
-          'Failed asserting that image "%s" is similar to image "%s".',
-           $other,
-           $this->filename
+            'Failed asserting that image "%s" is similar to image "%s".',
+            $other,
+            $this->filename
         );
 
-        if (!empty($description)) {
+        if (!empty( $description ))
+        {
             $failureDescription = $description . "\n" . $failureDescription;
         }
 
         throw new PHPUnit\Framework\ExpectationFailedException(
-          $failureDescription,
-          $comparisonFailure
+            $failureDescription,
+            $comparisonFailure
         );
     }
 
     /**
      * Provide test text
-     * 
+     *
      * @return string Test description
      */
-    public function toString()
+    public function toString() : string
     {
         return sprintf(
-          'is similar to "%s"', 
-          $this->filename
+            'is similar to "%s"',
+            $this->filename
         );
     }
 }
